@@ -7,7 +7,7 @@ from .helpers import runSubprocess
 
 class S3:
     def __init__(self):
-        self.bucket = os.path.join(config.s3_bucket, '')
+        self.bucket = os.path.join(config.s3_bucket, config.architecture, config.release_tag, 'o2', '')
         if not runSubprocess(['s3cmd', 'ls', self.bucket], failOnError=False) and not config.dry_run:
             logging.error('s3cmd is not installed or configured properly')
             sys.exit(1)
@@ -28,3 +28,14 @@ class S3:
             print(*command)
         else:
             runSubprocess(command)
+
+    def copy(self, source, dest, delete_removed = False):
+        source_bucket = os.path.join(config.s3_bucket, config.architecture, source, 'o2', '')
+        dest_bucket = os.path.join(config.s3_bucket, config.architecture, dest, 'o2', '')
+        command = ['s3cmd', 'sync', source_bucket, dest_bucket]
+        if delete_removed:
+            command.append('--delete-removed')
+        if config.dry_run:
+            print(*command)
+        else:
+            runSubprocess(command)
